@@ -375,10 +375,11 @@ class MainWindow(QtGui.QMainWindow):
             playersxbox=globalconverted[u'players_360']
             playersps3=globalconverted[u'players_ps3']
             #serverpc=globalconverted[u's_pc'][0]['servers']
-            
+            total=int(playerspc)+int(playersxbox)+int(playersps3)
             
             
             self.ui.statsshow.setText("Global:\n\n"
+                                      "Total players: "+str(total)+"\n"
                                       "Pc players: "+str(playerspc)+"\n"                                      
                                       "Xbox players: "+str(playersxbox)+"\n"
                                       "Ps3 players: "+str(playersps3)+"\n")
